blosc2.SplitMode
================

.. currentmodule:: blosc2

.. autoclass:: SplitMode
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SplitMode.ALWAYS_SPLIT
      ~SplitMode.NEVER_SPLIT
      ~SplitMode.AUTO_SPLIT
      ~SplitMode.FORWARD_COMPAT_SPLIT
   
   